@@ -25,6 +25,16 @@ from aalam_common.redisdb import redis_conn, baseapp_redisify_name
 from aalam_common.config import cfg
 
 
+# globals mostly used to cache frequently needed redis keys
+_globals = {}
+def get_common_rkey(rkey, redis_op='get'):
+    if not rkey.startswith("__common__"):
+        rkey = baseapp_redisify_name(rkey)
+    if rkey not in _globals:
+        _globals[rkey] = getattr(redis_conn, redis_op)(rkey)
+    return _globals[rkey]
+
+
 def _sign_and_send(prefix, header_key, method, hostname, url,
                    scheme="http", **kwargs):
     if scheme == "http+unix":
@@ -40,6 +50,8 @@ def _sign_and_send(prefix, header_key, method, hostname, url,
     if params:
         out_dict = {}
         for k, v in params.items():
+            if v is None:
+                continue
             if six.PY2:
                 if isinstance(v, unicode):
                     v = v.encode('utf-8')
@@ -162,18 +174,17 @@ class DateTimeRFC7231(object):
 
 class datetime(object):
     UTC = dateutil.tz.gettz('UTC')
-    USER_ZONE = None
     DATE_PATTERN = None
+    USER_ZONE = None
 
     @staticmethod
     def userzone():
-        if datetime.USER_ZONE is None:
+        if not datetime.USER_ZONE:
             try:
                 datetime.USER_ZONE = dateutil.tz.gettz(
                     Settings.get("timezone", "aalam", "base"))
-            except Exception:
+            except:
                 datetime.USER_ZONE = datetime.UTC
-
         return datetime.USER_ZONE
 
     def validator(func):
@@ -323,8 +334,8 @@ class mustachify(object):
 class Settings(object):
     @classmethod
     def get(cls, key, provider, app):
-        code = '/'.join([provider, app, key])
-        value = redis_conn.get(baseapp_redisify_name(code))
+        rkey = baseapp_redisify_name('setting-%s/%s/%s' % (provider, app, key))
+        value = get_common_rkey(rkey, "get")
         if not value:
             resp = request_local_server(
                 "GET",
@@ -337,6 +348,7 @@ class Settings(object):
             data = resp.json()
             value = data['value']
 
+            _globals[rkey] = value
         return value
 
 
