@@ -13,6 +13,7 @@ import os.path
 import socket
 import sys
 import six
+import string
 # from threading import Timer
 import mimetypes
 if sys.version_info[0] == 3:
@@ -87,16 +88,6 @@ class AALAMRequest(webob.Request):
                     raise zexc.ExpectedRouteArgs("database")
                 self.sqa_session = retval = zsqa.Session(database)
                 return retval
-            elif name == "sqa_sessions":
-                route_args = self.environ['wsgiorg.routing_args'][1]
-                databases = route_args.get("databases", None)
-                if not databases:
-                    logging.error("'databases' routing args not present")
-                    raise zexc.ExpectedRouteArgs("databases")
-                self.sqa_sessions = []
-                for db in databases:
-                    self.sqa_session.append(zsqa.Session(db))
-                return self.sqa_sessions
 
 
 def cleanup():
@@ -242,6 +233,8 @@ paste.app_factory = %(factory)s
         if self._state != zc.STATE_MIGRATE:
             self._pool = eventlet.GreenPool(size=self._num_threads)
             self._sock = self._setup_sock(wsgi_conf)
+
+        webob.exc.WSGIHTTPException.body_template_obj = string.Template('${explanation}')
         self.logger = logging.getLogger("wsgiapp")
         debug.init_logging(self.logger)
 
@@ -331,6 +324,25 @@ paste.app_factory = %(factory)s
             pass
 
 
+def report_exception(request, e):
+    if isinstance(e, webob.exc.HTTPException):
+         raise e
+
+    try:
+        exc_type, exc_value, exc_tb = sys.exc_info()
+        etb = debug.ExceptionTraceback(exc_type, exc_value, exc_tb)
+        lines = etb.format_exception()
+        eventlet.spawn_n(
+            report_bug, 'request', exc_type, exc_value, lines,
+            url="%s %s" % (request.method, request.path))
+    finally:
+        exc_type = exc_value = exc_tb = None
+        etb = None
+    import traceback
+    traceback.print_exc()
+    raise webob.exc.HTTPInternalServerError()
+
+
 class Middleware(object):
     def __init__(self, app):
         self._app = app
@@ -350,6 +362,7 @@ class Middleware(object):
 
     @webob.dec.wsgify(RequestClass=AALAMRequest)
     def __call__(self, request):
+
         result = self.pre(request)
 
         if result:
@@ -404,8 +417,12 @@ class BaseHandler(object):
             # negating the effect of url path decoding in UnixDomainHttpProtocol
             route[k] = v.encode('iso-8859-1').decode('utf8')
 
-        return self.respond(action, request, custom_serializer,
-                            custom_deserializer, inp_data_qualifier, **route)
+        try:
+            return self.respond(action, request, custom_serializer,
+                                custom_deserializer, inp_data_qualifier,
+                                **route)
+        except Exception as e:
+            report_exception(request, e)
 
     def reject_405(self):
         raise webob.exc.HTTPMethodNotAllowed()
@@ -510,22 +527,8 @@ class BaseHandler(object):
                     inp_data_qualifier
             raise webob.exc.HTTPBadRequest(explanation=msg)
         except Exception as e:
-            if getattr(e, "__module__", None) == "webob.exc":
-                raise e
-            try:
-                exc_type, exc_value, exc_tb = sys.exc_info()
-                etb = debug.ExceptionTraceback(exc_type, exc_value, exc_tb)
-                lines = etb.format_exception()
-                eventlet.spawn_n(
-                    report_bug, 'request', exc_type, exc_value, lines,
-                    url="%s %s" % (request.method, request.path))
-            finally:
-                exc_type = exc_value = exc_tb = None
-                etb = None
-            import traceback
-            traceback.print_exc()
             logging.error("Application failed for this url")
-            raise webob.exc.HTTPInternalServerError()
+            report_exception(request, e)
 
         if isinstance(app_ret, tuple):
             status_code = app_ret[0]
